# mysqld-integration-test

![](https://img.shields.io/badge/status-alpha-yellow)
version 0.0.1

## Overview
mysqld-integration-test is a python module that creates a temporary mysqld instance to use for testing your application. It is based on the `testing.mysqld` module which has not been updated recently.

## Download and Install
To install use pip:

    $ pip install mysql-integration-test

Or clone the repo:

    $ git clone https://github.com/jasondcamp/mysql-integration-test.git

